@@ -1,10 +1,11 @@
+
 as.bammdata <- function(x, ...) {
-	if (length(class(x) == 1) && class(x) == "bammdata") {
+	if (length(class(x)) == 1 && class(x) == "bammdata") {
 		return(x);
 	}
 	UseMethod("as.bammdata");
 }
-
+##' @export
 as.bammdata.credibleshiftset <- function(x, ...) {
 	obj <- x;
 	class(obj) <- "bammdata";
